@@ -32,6 +32,11 @@
 
 set -e
 
+function unix_to_dos {
+	sed -e "s/\n/\r\n/" $1 > temp_file
+	mv -f temp_file $1
+}
+
 if [ $# -lt 1 ] || [ $# -gt 2 ]; then
 	echo "Usage : Mingw-make-dist.sh <source tarball>."
 	exit 1
@@ -90,8 +95,12 @@ if [ ! -f $INSTALL/bin/libsndfile-1.dll ]; then
 	rmdir $INSTALL/bin
 	rm -rf $INSTALL/lib
 	rmdir $INSTALL/include
-	cp src/libsndfile.def $INSTALL/
-	cp Win32/README-precompiled-dll.txt $INSTALL/
+	cp src/libsndfile.def $INSTALL/libsndfile-1.def
+	cp Win32/README-precompiled-dll.txt Win32/testprog.c $INSTALL/
+	unix_to_dos $INSTALL/libsndfile-1.def
+	unix_to_dos $INSTALL/sndfile.h
+	unix_to_dos $INSTALL/README-precompiled-dll.txt
+	unix_to_dos $INSTALL/testprog.c
 	fi
 
 if [ ! -f $INSTALL/libsndfile-$VERSION.tar.gz ]; then
