@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1999-2005 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 1999-2006 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU Lesser General Public License as published by
@@ -43,6 +43,7 @@ typedef struct gsm610_tag
 	short			samples [WAV_W64_GSM610_SAMPLES] ;
 	unsigned char	block [WAV_W64_GSM610_BLOCKSIZE] ;
 
+	/* Damn I hate typedef-ed pointers; yes, gsm is a pointer type. */
 	gsm				gsm_data ;
 } GSM610_PRIVATE ;
 
@@ -78,15 +79,20 @@ gsm610_init	(SF_PRIVATE *psf)
 {	GSM610_PRIVATE	*pgsm610 ;
 	int		true_flag = 1 ;
 
+	if (psf->codec_data != NULL)
+	{	psf_log_printf (psf, "*** psf->codec_data is not NULL.\n") ;
+		return SFE_INTERNAL ;
+		} ;
+
 	if (psf->mode == SFM_RDWR)
 		return SFE_BAD_MODE_RW ;
 
 	psf->sf.seekable = SF_FALSE ;
 
-	if (! (pgsm610 = malloc (sizeof (GSM610_PRIVATE))))
+	if ((pgsm610 = calloc (1, sizeof (GSM610_PRIVATE))) == NULL)
 		return SFE_MALLOC_FAILED ;
 
-	psf->fdata = (void*) pgsm610 ;
+	psf->codec_data = pgsm610 ;
 
 	memset (pgsm610, 0, sizeof (GSM610_PRIVATE)) ;
 
@@ -96,34 +102,53 @@ Need separate gsm_data structs for encode and decode.
 
 ============================================================*/
 
-	if (! (pgsm610->gsm_data = gsm_create ()))
+	if ((pgsm610->gsm_data = gsm_create ()) == NULL)
 		return SFE_MALLOC_FAILED ;
 
-	if ((psf->sf.format & SF_FORMAT_TYPEMASK) == SF_FORMAT_WAV ||
-				(psf->sf.format & SF_FORMAT_TYPEMASK) == SF_FORMAT_W64)
-	{	gsm_option (pgsm610->gsm_data, GSM_OPT_WAV49, &true_flag) ;
+	switch (psf->sf.format & SF_FORMAT_TYPEMASK)
+	{	case SF_FORMAT_WAV :
+		case SF_FORMAT_WAVEX :
+		case SF_FORMAT_W64 :
+			gsm_option (pgsm610->gsm_data, GSM_OPT_WAV49, &true_flag) ;
 
-		pgsm610->encode_block = gsm610_wav_encode_block ;
-		pgsm610->decode_block = gsm610_wav_decode_block ;
+			pgsm610->encode_block = gsm610_wav_encode_block ;
+			pgsm610->decode_block = gsm610_wav_decode_block ;
 
-		pgsm610->samplesperblock = WAV_W64_GSM610_SAMPLES ;
-		pgsm610->blocksize = WAV_W64_GSM610_BLOCKSIZE ;
-		}
-	else
-	{	pgsm610->encode_block = gsm610_encode_block ;
-		pgsm610->decode_block = gsm610_decode_block ;
+			pgsm610->samplesperblock = WAV_W64_GSM610_SAMPLES ;
+			pgsm610->blocksize = WAV_W64_GSM610_BLOCKSIZE ;
+			break ;
 
-		pgsm610->samplesperblock = GSM610_SAMPLES ;
-		pgsm610->blocksize = GSM610_BLOCKSIZE ;
+		case SF_FORMAT_AIFF :
+		case SF_FORMAT_RAW :
+			pgsm610->encode_block = gsm610_encode_block ;
+			pgsm610->decode_block = gsm610_decode_block ;
+
+			pgsm610->samplesperblock = GSM610_SAMPLES ;
+			pgsm610->blocksize = GSM610_BLOCKSIZE ;
+			break ;
+
+		default :
+			return SFE_INTERNAL ;
+			break ;
 		} ;
 
 	if (psf->mode == SFM_READ)
-	{	if (psf->datalength % pgsm610->blocksize)
-		{	psf_log_printf (psf, "*** Warning : data chunk seems to be truncated.\n") ;
-			pgsm610->blocks = psf->datalength / pgsm610->blocksize + 1 ;
+	{	if (psf->datalength % pgsm610->blocksize == 0)
+			pgsm610->blocks = psf->datalength / pgsm610->blocksize ;
+		else if (psf->datalength % pgsm610->blocksize == 1 && pgsm610->blocksize == GSM610_BLOCKSIZE)
+		{	/*
+			**	Weird AIFF specific case.
+			**	AIFF chunks must be at an even offset from the start of file and
+			**	GSM610_BLOCKSIZE is odd which can result in an odd length SSND
+			**	chunk. The SSND chunk then gets padded on write which means that
+			**	when it is read the datalength is too big by 1.
+			*/
+			pgsm610->blocks = psf->datalength / pgsm610->blocksize ;
 			}
 		else
-			pgsm610->blocks = psf->datalength / pgsm610->blocksize ;
+		{	psf_log_printf (psf, "*** Warning : data chunk seems to be truncated.\n") ;
+			pgsm610->blocks = psf->datalength / pgsm610->blocksize + 1 ;
+			} ;
 
 		psf->sf.frames = pgsm610->samplesperblock * pgsm610->blocks ;
 
@@ -145,7 +170,8 @@ Need separate gsm_data structs for encode and decode.
 		psf->write_double	= gsm610_write_d ;
 		} ;
 
-	psf->close = gsm610_close ;
+	psf->codec_close = gsm610_close ;
+
 	psf->seek = gsm610_seek ;
 
 	psf->filelength = psf_get_filelen (psf) ;
@@ -215,7 +241,7 @@ gsm610_read_block	(SF_PRIVATE *psf, GSM610_PRIVATE *pgsm610, short *ptr, int len
 
 	while (indx < len)
 	{	if (pgsm610->blockcount >= pgsm610->blocks && pgsm610->samplecount >= pgsm610->samplesperblock)
-		{	memset (&(ptr [indx]), 0, (size_t) ((len - indx) * sizeof (short))) ;
+		{	memset (&(ptr [indx]), 0, (len - indx) * sizeof (short)) ;
 			return total ;
 			} ;
 
@@ -240,9 +266,9 @@ gsm610_read_s	(SF_PRIVATE *psf, short *ptr, sf_count_t len)
 	int			readcount, count ;
 	sf_count_t	total = 0 ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	while (len > 0)
 	{	readcount = (len > 0x10000000) ? 0x1000000 : (int) len ;
@@ -266,9 +292,9 @@ gsm610_read_i	(SF_PRIVATE *psf, int *ptr, sf_count_t len)
 	int			k, bufferlen, readcount = 0, count ;
 	sf_count_t	total = 0 ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	sptr = psf->u.sbuf ;
 	bufferlen = ARRAY_LEN (psf->u.sbuf) ;
@@ -292,9 +318,9 @@ gsm610_read_f	(SF_PRIVATE *psf, float *ptr, sf_count_t len)
 	sf_count_t	total = 0 ;
 	float		normfact ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	normfact = (psf->norm_float == SF_TRUE) ? 1.0 / ((float) 0x8000) : 1.0 ;
 
@@ -322,9 +348,9 @@ gsm610_read_d	(SF_PRIVATE *psf, double *ptr, sf_count_t len)
 
 	normfact = (psf->norm_double == SF_TRUE) ? 1.0 / ((double) 0x8000) : 1.0 ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	sptr = psf->u.sbuf ;
 	bufferlen = ARRAY_LEN (psf->u.sbuf) ;
@@ -347,9 +373,9 @@ gsm610_seek	(SF_PRIVATE *psf, int mode, sf_count_t offset)
 
 	mode = mode ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	if (psf->dataoffset < 0)
 	{	psf->error = SFE_BAD_SEEK ;
@@ -469,9 +495,9 @@ gsm610_write_s	(SF_PRIVATE *psf, const short *ptr, sf_count_t len)
 	int			writecount, count ;
 	sf_count_t	total = 0 ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	while (len > 0)
 	{	writecount = (len > 0x10000000) ? 0x10000000 : (int) len ;
@@ -495,9 +521,9 @@ gsm610_write_i	(SF_PRIVATE *psf, const int *ptr, sf_count_t len)
 	int			k, bufferlen, writecount = 0, count ;
 	sf_count_t	total = 0 ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	sptr = psf->u.sbuf ;
 	bufferlen = ARRAY_LEN (psf->u.sbuf) ;
@@ -521,9 +547,9 @@ gsm610_write_f	(SF_PRIVATE *psf, const float *ptr, sf_count_t len)
 	sf_count_t	total = 0 ;
 	float		normfact ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	normfact = (psf->norm_float == SF_TRUE) ? (1.0 * 0x7FFF) : 1.0 ;
 
@@ -549,9 +575,9 @@ gsm610_write_d	(SF_PRIVATE *psf, const double *ptr, sf_count_t len)
 	sf_count_t	total = 0 ;
 	double		normfact ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	normfact = (psf->norm_double == SF_TRUE) ? (1.0 * 0x7FFF) : 1.0 ;
 
@@ -573,10 +599,10 @@ static int
 gsm610_close	(SF_PRIVATE *psf)
 {	GSM610_PRIVATE *pgsm610 ;
 
-	if (! psf->fdata)
+	if (psf->codec_data == NULL)
 		return 0 ;
 
-	pgsm610 = (GSM610_PRIVATE*) psf->fdata ;
+	pgsm610 = (GSM610_PRIVATE*) psf->codec_data ;
 
 	if (psf->mode == SFM_WRITE)
 	{	/*	If a block has been partially assembled, write it out
@@ -585,9 +611,6 @@ gsm610_close	(SF_PRIVATE *psf)
 
 		if (pgsm610->samplecount && pgsm610->samplecount < pgsm610->samplesperblock)
 			pgsm610->encode_block (psf, pgsm610) ;
-
-		if (psf->write_header)
-			psf->write_header (psf, SF_TRUE) ;
 		} ;
 
 	if (pgsm610->gsm_data)
