@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2001-2004 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 2001-2005 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** This program is free software ; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#include "config.h"
+#include "sfconfig.h"
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -25,7 +25,7 @@
 #include <sys/stat.h>
 #include <math.h>
 
-#ifdef HAVE_UNISTD_H
+#if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
@@ -106,6 +106,16 @@ main (int argc, char *argv [])
 		test_count++ ;
 		} ;
 
+	if (do_all || ! strcmp (argv [1], "caf"))
+	{	update_header_test ("header.caf", SF_FORMAT_CAF) ;
+		update_seek_short_test ("header_short.caf", SF_FORMAT_CAF) ;
+		update_seek_int_test ("header_int.caf", SF_FORMAT_CAF) ;
+		update_seek_float_test ("header_float.caf", SF_FORMAT_CAF) ;
+		update_seek_double_test ("header_double.caf", SF_FORMAT_CAF) ;
+		/* extra_header_test ("extra.caf", SF_FORMAT_CAF) ; */
+		test_count++ ;
+		} ;
+
 	if (do_all || ! strcmp (argv [1], "nist"))
 	{	update_header_test ("header.nist", SF_FORMAT_NIST) ;
 		update_seek_short_test ("header_short.nist", SF_FORMAT_NIST) ;
@@ -216,7 +226,7 @@ update_header_sub (const char *filename, int typemajor, int write_mode)
 
 	frames = BUFFER_LEN / sfinfo.channels ;
 
-	outfile = test_open_file_or_die (filename, write_mode, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, write_mode, &sfinfo, SF_TRUE, __LINE__) ;
 
 	for (k = 0 ; k < BUFFER_LEN ; k++)
 		data_out [k] = k + 1 ;
@@ -224,7 +234,7 @@ update_header_sub (const char *filename, int typemajor, int write_mode)
 
 	if (typemajor != SF_FORMAT_HTK)
 	{	/* The HTK header is not correct when the file is first written. */
-		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 		sf_close (infile) ;
 		} ;
 
@@ -234,7 +244,7 @@ update_header_sub (const char *filename, int typemajor, int write_mode)
 	** Open file and check log buffer for an error. If header update failed
 	** the the log buffer will contain errors.
 	*/
-	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 	check_log_buffer_or_die (infile, __LINE__) ;
 
 	if (sfinfo.frames < BUFFER_LEN || sfinfo.frames > BUFFER_LEN + 50)
@@ -259,7 +269,7 @@ update_header_sub (const char *filename, int typemajor, int write_mode)
 	test_write_int_or_die (outfile, 0, data_out, BUFFER_LEN, __LINE__) ;
 
 	/* Open file again and make sure no errors in log buffer. */
-	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 	check_log_buffer_or_die (infile, __LINE__) ;
 
 	if (sfinfo.frames < 2 * BUFFER_LEN || sfinfo.frames > 2 * BUFFER_LEN + 50)
@@ -322,11 +332,11 @@ update_seek_short_test	(const char *filename, int filetype)
 	if (sf_format_check (&sfinfo) == SF_FALSE)
 		sfinfo.channels = 1 ;
 
-	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_close (outfile) ;
 
 	/* Open again for read/write. */
-	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, SF_TRUE, __LINE__) ;
 
 	/*
 	** In auto header update mode, seeking to the end of the file with
@@ -346,7 +356,7 @@ update_seek_short_test	(const char *filename, int filetype)
 		test_seek_or_die (outfile, 0, SEEK_END, k * frames, sfinfo.channels, __LINE__) ;
 
 		/* Open file again and make sure no errors in log buffer. */
-		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 		check_log_buffer_or_die (infile, __LINE__) ;
 		sf_close (infile) ;
 
@@ -388,11 +398,11 @@ update_seek_int_test	(const char *filename, int filetype)
 	if (sf_format_check (&sfinfo) == SF_FALSE)
 		sfinfo.channels = 1 ;
 
-	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_close (outfile) ;
 
 	/* Open again for read/write. */
-	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, SF_TRUE, __LINE__) ;
 
 	/*
 	** In auto header update mode, seeking to the end of the file with
@@ -412,7 +422,7 @@ update_seek_int_test	(const char *filename, int filetype)
 		test_seek_or_die (outfile, 0, SEEK_END, k * frames, sfinfo.channels, __LINE__) ;
 
 		/* Open file again and make sure no errors in log buffer. */
-		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 		check_log_buffer_or_die (infile, __LINE__) ;
 		sf_close (infile) ;
 
@@ -454,11 +464,11 @@ update_seek_float_test	(const char *filename, int filetype)
 	if (sf_format_check (&sfinfo) == SF_FALSE)
 		sfinfo.channels = 1 ;
 
-	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_close (outfile) ;
 
 	/* Open again for read/write. */
-	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, SF_TRUE, __LINE__) ;
 
 	/*
 	** In auto header update mode, seeking to the end of the file with
@@ -478,7 +488,7 @@ update_seek_float_test	(const char *filename, int filetype)
 		test_seek_or_die (outfile, 0, SEEK_END, k * frames, sfinfo.channels, __LINE__) ;
 
 		/* Open file again and make sure no errors in log buffer. */
-		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 		check_log_buffer_or_die (infile, __LINE__) ;
 		sf_close (infile) ;
 
@@ -520,11 +530,11 @@ update_seek_double_test	(const char *filename, int filetype)
 	if (sf_format_check (&sfinfo) == SF_FALSE)
 		sfinfo.channels = 1 ;
 
-	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_close (outfile) ;
 
 	/* Open again for read/write. */
-	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, __LINE__) ;
+	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, SF_TRUE, __LINE__) ;
 
 	/*
 	** In auto header update mode, seeking to the end of the file with
@@ -544,7 +554,7 @@ update_seek_double_test	(const char *filename, int filetype)
 		test_seek_or_die (outfile, 0, SEEK_END, k * frames, sfinfo.channels, __LINE__) ;
 
 		/* Open file again and make sure no errors in log buffer. */
-		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+		infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 		check_log_buffer_or_die (infile, __LINE__) ;
 		sf_close (infile) ;
 
@@ -592,9 +602,9 @@ extra_header_test (const char *filename, int filetype)
 	frames = ARRAY_LEN (buffer) / sfinfo.channels ;
 
 	/* Test the file with extra header data. */
-	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, 399) ;
+	outfile = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, 409) ;
 	sf_set_string (outfile, SF_STR_TITLE, filename) ;
-	test_writef_short_or_die (outfile, k, buffer, frames, 401) ;
+	test_writef_short_or_die (outfile, k, buffer, frames, 411) ;
 	sf_set_string (outfile, SF_STR_COPYRIGHT, "(c) 1980 Erik") ;
 	sf_close (outfile) ;
 
@@ -621,7 +631,7 @@ extra_header_test (const char *filename, int filetype)
 	hexdump_file (filename, 0, 100000) ;
 
 	/* Open again for read/write. */
-	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, 428) ;
+	outfile = test_open_file_or_die (filename, SFM_RDWR, &sfinfo, 438) ;
 
 	/*
 	** In auto header update mode, seeking to the end of the file with
@@ -642,26 +652,26 @@ extra_header_test (const char *filename, int filetype)
 		memset (buffer, 0xA0 + k, sizeof (buffer)) ;
 
 
-		test_seek_or_die (outfile, k * frames, SEEK_SET, k * frames, sfinfo.channels, 449) ;
-		test_seek_or_die (outfile, 0, SEEK_END, k * frames, sfinfo.channels, 450) ;
+		test_seek_or_die (outfile, k * frames, SEEK_SET, k * frames, sfinfo.channels, 459) ;
+		test_seek_or_die (outfile, 0, SEEK_END, k * frames, sfinfo.channels, 460) ;
 
 		/* Open file again and make sure no errors in log buffer. */
 		if (0)
-		{	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, 454) ;
-			check_log_buffer_or_die (infile, 455) ;
+		{	infile = test_open_file_or_die (filename, SFM_READ, &sfinfo, 464) ;
+			check_log_buffer_or_die (infile, 465) ;
 			sf_close (infile) ;
 			} ;
 
 		if (sfinfo.frames != k * frames)
-		{	printf ("\n\nLine %d : Incorrect sample count (%ld should be %ld)\n", 460, SF_COUNT_TO_LONG (sfinfo.frames), SF_COUNT_TO_LONG (k + frames)) ;
+		{	printf ("\n\nLine %d : Incorrect sample count (%ld should be %ld)\n", 470, SF_COUNT_TO_LONG (sfinfo.frames), SF_COUNT_TO_LONG (k + frames)) ;
 			dump_log_buffer (infile) ;
 			exit (1) ;
 			} ;
 
 		if ((k & 1) == 0)
-			test_write_short_or_die (outfile, k, buffer, sfinfo.channels * frames, 466) ;
+			test_write_short_or_die (outfile, k, buffer, sfinfo.channels * frames, 476) ;
 		else
-			test_writef_short_or_die (outfile, k, buffer, frames, 468) ;
+			test_writef_short_or_die (outfile, k, buffer, frames, 478) ;
 		hexdump_file (filename, 0, 100000) ;
 		} ;
 
