@@ -16,13 +16,13 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-#include "config.h"
+#include "sfconfig.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 
-#ifdef HAVE_UNISTD_H
+#if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
@@ -31,7 +31,7 @@
 #include "float_cast.h"
 #include "utils.h"
 
-#define	BUFFER_SIZE		(1<<15)
+#define	BUFFER_SIZE		(1<<12)
 
 static void	lrintf_test (void) ;
 
@@ -43,11 +43,18 @@ static void	pcm_test_bits_32	(const char *filename, int filetype, int hash) ;
 static void pcm_test_float	(const char *filename, int filetype, int hash, int replace_float) ;
 static void pcm_test_double	(const char *filename, int filetype, int hash, int replace_float) ;
 
+typedef union
+{	double	d [BUFFER_SIZE + 1];
+	float	f [BUFFER_SIZE + 1];
+	int		i [BUFFER_SIZE + 1];
+	short	s [BUFFER_SIZE + 1];
+} BUFFER ;
+
 /* Data written to the file. */
-static	double	data_out [(BUFFER_SIZE / sizeof (double)) + 1] ;
+static	BUFFER	data_out ;
 
 /* Data read back from the file. */
-static	double	data_in	[(BUFFER_SIZE / sizeof (double)) + 1] ;
+static	BUFFER	data_in ;
 
 int
 main (void)
@@ -99,8 +106,8 @@ lrintf_test (void)
 
 	items = 1024 ;
 
-	float_data = (float*) data_out ;
-	int_data = (int*) data_in ;
+	float_data = data_out.f ;
+	int_data = data_in.i ;
 
 	for (k = 0 ; k < items ; k++)
 		float_data [k] = (k * ((k % 2) ? 333333.0 : -333333.0)) ;
@@ -133,8 +140,8 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 
 	items = 127 ;
 
-	short_out = (short*) data_out ;
-	short_in = (short*) data_in ;
+	short_out = data_out.s ;
+	short_in = data_in.s ;
 
 	zero_count = 0 ;
 	for (k = 0 ; k < items ; k++)
@@ -152,7 +159,7 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	test_write_short_or_die (file, 0, short_out, items, __LINE__) ;
 
@@ -160,7 +167,7 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 
 	memset (short_in, 0, items * sizeof (short)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -197,8 +204,8 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	int_out = (int*) data_out ;
-	int_in = (int*) data_in ;
+	int_out = data_out.i ;
+	int_in = data_in.i ;
 	for (k = 0 ; k < items ; k++)
 	{	int_out [k] = ((k * ((k % 2) ? 1 : -1)) << 24) ;
 		zero_count = int_out [k] ? zero_count : zero_count + 1 ;
@@ -214,7 +221,7 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	test_write_int_or_die (file, 0, int_out, items, __LINE__) ;
 
@@ -222,7 +229,7 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 
 	memset (int_in, 0, items * sizeof (int)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -257,8 +264,8 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	float_out = (float*) data_out ;
-	float_in = (float*) data_in ;
+	float_out = data_out.f ;
+	float_in = data_in.f ;
 	for (k = 0 ; k < items ; k++)
 	{	float_out [k] = (k * ((k % 2) ? 1 : -1)) ;
 		zero_count = (fabs (float_out [k]) > 1e-10) ? zero_count : zero_count + 1 ;
@@ -274,7 +281,7 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	sf_command (file, SFC_SET_NORM_FLOAT, NULL, SF_FALSE) ;
 
@@ -284,7 +291,7 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 
 	memset (float_in, 0, items * sizeof (float)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -321,8 +328,8 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	double_out = (double*) data_out ;
-	double_in = (double*) data_in ;
+	double_out = data_out.d ;
+	double_in = data_in.d ;
 	for (k = 0 ; k < items ; k++)
 	{	double_out [k] = (k * ((k % 2) ? 1 : -1)) ;
 		zero_count = (fabs (double_out [k]) > 1e-10) ? zero_count : zero_count + 1 ;
@@ -338,7 +345,7 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	sf_command (file, SFC_SET_NORM_DOUBLE, NULL, SF_FALSE) ;
 
@@ -348,7 +355,7 @@ pcm_test_bits_8 (const char *filename, int filetype, int hash)
 
 	memset (double_in, 0, items * sizeof (double)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -400,8 +407,8 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 
 	items = 1024 ;
 
-	short_out = (short*) data_out ;
-	short_in = (short*) data_in ;
+	short_out = data_out.s ;
+	short_in = data_in.s ;
 
 	zero_count = 0 ;
 	for (k = 0 ; k < items ; k++)
@@ -419,7 +426,7 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	test_write_short_or_die (file, 0, short_out, items, __LINE__) ;
 
@@ -427,7 +434,7 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 
 	memset (short_in, 0, items * sizeof (short)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -464,8 +471,8 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	int_out = (int*) data_out ;
-	int_in = (int*) data_in ;
+	int_out = data_out.i ;
+	int_in = data_in.i ;
 	for (k = 0 ; k < items ; k++)
 	{	int_out [k] = ((k * ((k % 2) ? 3 : -3)) << 16) ;
 		zero_count = int_out [k] ? zero_count : zero_count + 1 ;
@@ -481,7 +488,7 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	test_write_int_or_die (file, 0, int_out, items, __LINE__) ;
 
@@ -489,7 +496,7 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 
 	memset (int_in, 0, items * sizeof (int)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -524,8 +531,8 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	float_out = (float*) data_out ;
-	float_in = (float*) data_in ;
+	float_out = data_out.f ;
+	float_in = data_in.f ;
 	for (k = 0 ; k < items ; k++)
 	{	float_out [k] = (k * ((k % 2) ? 3 : -3)) ;
 		zero_count = (fabs (float_out [k]) > 1e-10) ? zero_count : zero_count + 1 ;
@@ -541,7 +548,7 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	sf_command (file, SFC_SET_NORM_FLOAT, NULL, SF_FALSE) ;
 
@@ -551,7 +558,7 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 
 	memset (float_in, 0, items * sizeof (float)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -588,8 +595,8 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	double_out = (double*) data_out ;
-	double_in = (double*) data_in ;
+	double_out = data_out.d ;
+	double_in = data_in.d ;
 	for (k = 0 ; k < items ; k++)
 	{	double_out [k] = (k * ((k % 2) ? 3 : -3)) ;
 		zero_count = (fabs (double_out [k]) > 1e-10) ? zero_count : zero_count + 1 ;
@@ -605,7 +612,7 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	sf_command (file, SFC_SET_NORM_DOUBLE, NULL, SF_FALSE) ;
 
@@ -615,7 +622,7 @@ pcm_test_bits_16 (const char *filename, int filetype, int hash)
 
 	memset (double_in, 0, items * sizeof (double)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -667,8 +674,8 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 
 	items = 1024 ;
 
-	short_out = (short*) data_out ;
-	short_in = (short*) data_in ;
+	short_out = data_out.s ;
+	short_in = data_in.s ;
 
 	zero_count = 0 ;
 	for (k = 0 ; k < items ; k++)
@@ -686,7 +693,7 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	test_write_short_or_die (file, 0, short_out, items, __LINE__) ;
 
@@ -694,7 +701,7 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 
 	memset (short_in, 0, items * sizeof (short)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -731,8 +738,8 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	int_out = (int*) data_out ;
-	int_in = (int*) data_in ;
+	int_out = data_out.i ;
+	int_in = data_in.i ;
 	for (k = 0 ; k < items ; k++)
 	{	int_out [k] = ((k * ((k % 2) ? 3333 : -3333)) << 8) ;
 		zero_count = int_out [k] ? zero_count : zero_count + 1 ;
@@ -748,7 +755,7 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	test_write_int_or_die (file, 0, int_out, items, __LINE__) ;
 
@@ -756,7 +763,7 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 
 	memset (int_in, 0, items * sizeof (int)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -791,8 +798,8 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	float_out = (float*) data_out ;
-	float_in = (float*) data_in ;
+	float_out = data_out.f ;
+	float_in = data_in.f ;
 	for (k = 0 ; k < items ; k++)
 	{	float_out [k] = (k * ((k % 2) ? 3333 : -3333)) ;
 		zero_count = (fabs (float_out [k]) > 1e-10) ? zero_count : zero_count + 1 ;
@@ -808,7 +815,7 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	sf_command (file, SFC_SET_NORM_FLOAT, NULL, SF_FALSE) ;
 
@@ -818,7 +825,7 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 
 	memset (float_in, 0, items * sizeof (float)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -855,8 +862,8 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	double_out = (double*) data_out ;
-	double_in = (double*) data_in ;
+	double_out = data_out.d ;
+	double_in = data_in.d ;
 	for (k = 0 ; k < items ; k++)
 	{	double_out [k] = (k * ((k % 2) ? 3333 : -3333)) ;
 		zero_count = (fabs (double_out [k]) > 1e-10) ? zero_count : zero_count + 1 ;
@@ -872,7 +879,7 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	sf_command (file, SFC_SET_NORM_DOUBLE, NULL, SF_FALSE) ;
 
@@ -882,7 +889,7 @@ pcm_test_bits_24 (const char *filename, int filetype, int hash)
 
 	memset (double_in, 0, items * sizeof (double)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -934,8 +941,8 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 
 	items = 1024 ;
 
-	short_out = (short*) data_out ;
-	short_in = (short*) data_in ;
+	short_out = data_out.s ;
+	short_in = data_in.s ;
 
 	zero_count = 0 ;
 	for (k = 0 ; k < items ; k++)
@@ -953,7 +960,7 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	test_write_short_or_die (file, 0, short_out, items, __LINE__) ;
 
@@ -961,7 +968,7 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 
 	memset (short_in, 0, items * sizeof (short)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -998,8 +1005,8 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	int_out = (int*) data_out ;
-	int_in = (int*) data_in ;
+	int_out = data_out.i ;
+	int_in = data_in.i ;
 	for (k = 0 ; k < items ; k++)
 	{	int_out [k] = (k * ((k % 2) ? 333333 : -333333)) ;
 		zero_count = int_out [k] ? zero_count : zero_count + 1 ;
@@ -1015,7 +1022,7 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	test_write_int_or_die (file, 0, int_out, items, __LINE__) ;
 
@@ -1023,7 +1030,7 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 
 	memset (int_in, 0, items * sizeof (int)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -1058,8 +1065,8 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	float_out = (float*) data_out ;
-	float_in = (float*) data_in ;
+	float_out = data_out.f ;
+	float_in = data_in.f ;
 	for (k = 0 ; k < items ; k++)
 	{	float_out [k] = (k * ((k % 2) ? 333333 : -333333)) ;
 		zero_count = (fabs (float_out [k]) > 1e-10) ? zero_count : zero_count + 1 ;
@@ -1075,7 +1082,7 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	sf_command (file, SFC_SET_NORM_FLOAT, NULL, SF_FALSE) ;
 
@@ -1085,7 +1092,7 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 
 	memset (float_in, 0, items * sizeof (float)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -1122,8 +1129,8 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 	*/
 	zero_count = 0 ;
 
-	double_out = (double*) data_out ;
-	double_in = (double*) data_in ;
+	double_out = data_out.d ;
+	double_in = data_in.d ;
 	for (k = 0 ; k < items ; k++)
 	{	double_out [k] = (k * ((k % 2) ? 333333 : -333333)) ;
 		zero_count = (fabs (double_out [k]) > 1e-10) ? zero_count : zero_count + 1 ;
@@ -1139,7 +1146,7 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 
 	sf_command (file, SFC_SET_NORM_DOUBLE, NULL, SF_FALSE) ;
 
@@ -1149,7 +1156,7 @@ pcm_test_bits_32 (const char *filename, int filetype, int hash)
 
 	memset (double_in, 0, items * sizeof (double)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 
 	if (sfinfo.format != filetype)
 	{	printf ("\n\nLine %d: Returned format incorrect (0x%08X => 0x%08X).\n", __LINE__, filetype, sfinfo.format) ;
@@ -1200,9 +1207,9 @@ pcm_test_float (const char *filename, int filetype, int hash, int replace_float)
 
 	print_test_name ("pcm_test_float", filename) ;
 
-	items = BUFFER_SIZE / sizeof (double) ;
+	items = BUFFER_SIZE ;
 
-	data = (double*) data_out ;
+	data = data_out.d ;
 	for (sign = 1, k = 0 ; k < items ; k++)
 	{	data [k] = ((double) (k * sign)) / 100.0 ;
 		sign = (sign > 0) ? -1 : 1 ;
@@ -1213,7 +1220,7 @@ pcm_test_float (const char *filename, int filetype, int hash, int replace_float)
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_command (file, SFC_TEST_IEEE_FLOAT_REPLACE, NULL, replace_float) ;
 	if (replace_float && string_in_log_buffer (file, "Using IEEE replacement") == 0)
 	{	printf ("\n\nLine %d : Float replacement code not working.\n\n", __LINE__) ;
@@ -1232,7 +1239,7 @@ pcm_test_float (const char *filename, int filetype, int hash, int replace_float)
 	if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_RAW)
 		memset (&sfinfo, 0, sizeof (sfinfo)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_command (file, SFC_TEST_IEEE_FLOAT_REPLACE, NULL, replace_float) ;
 	if (replace_float && string_in_log_buffer (file, "Using IEEE replacement") == 0)
 	{	printf ("\n\nLine %d : Float replacement code not working.\n\n", __LINE__) ;
@@ -1324,9 +1331,9 @@ pcm_test_float (const char *filename, int filetype, int hash, int replace_float)
 		return ;
 		} ;
 
-	items = BUFFER_SIZE / sizeof (double) ;
+	items = BUFFER_SIZE ;
 
-	data = (double*) data_out ;
+	data = data_out.d ;
 	for (sign = -1, k = 0 ; k < items ; k++)
 		data [k] = ((double) k) / 100.0 * (sign *= -1) ;
 
@@ -1337,7 +1344,7 @@ pcm_test_float (const char *filename, int filetype, int hash, int replace_float)
 
 	frames = items / sfinfo.channels ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_command (file, SFC_TEST_IEEE_FLOAT_REPLACE, NULL, replace_float) ;
 	if (replace_float && string_in_log_buffer (file, "Using IEEE replacement") == 0)
 	{	printf ("\n\nLine %d : Float replacement code not working.\n\n", __LINE__) ;
@@ -1356,7 +1363,7 @@ pcm_test_float (const char *filename, int filetype, int hash, int replace_float)
 	if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_RAW)
 		memset (&sfinfo, 0, sizeof (sfinfo)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_command (file, SFC_TEST_IEEE_FLOAT_REPLACE, NULL, replace_float) ;
 	if (replace_float && string_in_log_buffer (file, "Using IEEE replacement") == 0)
 	{	printf ("\n\nLine %d : Float replacement code not working.\n\n", __LINE__) ;
@@ -1456,9 +1463,9 @@ pcm_test_double (const char *filename, int	filetype, int hash, int replace_float
 
 	print_test_name ("pcm_test_double", filename) ;
 
-	items = BUFFER_SIZE / sizeof (double) ;
+	items = BUFFER_SIZE ;
 
-	data = (double*) data_out ;
+	data = data_out.d ;
 	for (sign = 1, k = 0 ; k < items ; k++)
 	{	data [k] = ((double) (k * sign)) / 100.0 ;
 		sign = (sign > 0) ? -1 : 1 ;
@@ -1469,7 +1476,7 @@ pcm_test_double (const char *filename, int	filetype, int hash, int replace_float
 	sfinfo.channels		= 1 ;
 	sfinfo.format		= filetype ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_command (file, SFC_TEST_IEEE_FLOAT_REPLACE, NULL, replace_float) ;
 	if (replace_float && string_in_log_buffer (file, "Using IEEE replacement") == 0)
 	{	printf ("\n\nLine %d : Float replacement code not working.\n\n", __LINE__) ;
@@ -1495,7 +1502,7 @@ pcm_test_double (const char *filename, int	filetype, int hash, int replace_float
 	if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_RAW)
 		memset (&sfinfo, 0, sizeof (sfinfo)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_command (file, SFC_TEST_IEEE_FLOAT_REPLACE, NULL, replace_float) ;
 	if (replace_float && string_in_log_buffer (file, "Using IEEE replacement") == 0)
 	{	printf ("\n\nLine %d : Float replacement code not working.\n\n", __LINE__) ;
@@ -1590,9 +1597,9 @@ pcm_test_double (const char *filename, int	filetype, int hash, int replace_float
 		return ;
 		} ;
 
-	items = BUFFER_SIZE / sizeof (double) ;
+	items = BUFFER_SIZE ;
 
-	data = (double*) data_out ;
+	data = data_out.d ;
 	for (sign = -1, k = 0 ; k < items ; k++)
 		data [k] = ((double) k) / 100.0 * (sign *= -1) ;
 
@@ -1603,7 +1610,7 @@ pcm_test_double (const char *filename, int	filetype, int hash, int replace_float
 
 	frames = items / sfinfo.channels ;
 
-	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_command (file, SFC_TEST_IEEE_FLOAT_REPLACE, NULL, replace_float) ;
 	if (replace_float && string_in_log_buffer (file, "Using IEEE replacement") == 0)
 	{	printf ("\n\nLine %d : Float replacement code not working.\n\n", __LINE__) ;
@@ -1629,7 +1636,7 @@ pcm_test_double (const char *filename, int	filetype, int hash, int replace_float
 	if ((filetype & SF_FORMAT_TYPEMASK) != SF_FORMAT_RAW)
 		memset (&sfinfo, 0, sizeof (sfinfo)) ;
 
-	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, __LINE__) ;
+	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, SF_TRUE, __LINE__) ;
 	sf_command (file, SFC_TEST_IEEE_FLOAT_REPLACE, NULL, replace_float) ;
 	if (replace_float && string_in_log_buffer (file, "Using IEEE replacement") == 0)
 	{	printf ("\n\nLine %d : Float replacement code not working.\n\n", __LINE__) ;
