@@ -63,6 +63,8 @@ main (int argc, char *argv [])
 
 	if (do_all || ! strcmp (argv [1], "wav"))
 	{	test_float_peak ("peak_float.wav", SF_FORMAT_WAV | SF_FORMAT_FLOAT) ;
+		test_float_peak ("peak_float.wavex", SF_FORMAT_WAVEX | SF_FORMAT_FLOAT) ;
+		test_float_peak ("peak_float.rifx", SF_ENDIAN_BIG | SF_FORMAT_WAV | SF_FORMAT_FLOAT) ;
 		test_count++ ;
 		} ;
 
@@ -113,6 +115,9 @@ test_float_peak (const char *filename, int filetype)
 	/* Write a file with PEAK chunks. */
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, 0, __LINE__) ;
 
+	/* Try to confuse the header writer by adding a removing the PEAK chunk. */
+	sf_command (file, SFC_SET_ADD_PEAK_CHUNK, NULL, SF_TRUE) ;
+	sf_command (file, SFC_SET_ADD_PEAK_CHUNK, NULL, SF_FALSE) ;
 	sf_command (file, SFC_SET_ADD_PEAK_CHUNK, NULL, SF_TRUE) ;
 
 	/*	Write the data in four passed. The data is designed so that peaks will
@@ -140,6 +145,27 @@ test_float_peak (const char *filename, int filetype)
 		exit (1) ;
 		} ;
 
+	/* Check these two commands. */
+	if (sf_command (file, SFC_GET_SIGNAL_MAX, data, sizeof (double)) == SF_FALSE)
+	{	printf ("\n\nLine %d: Command should have returned SF_TRUE.\n", __LINE__) ;
+		exit (1) ;
+		} ;
+
+	if (fabs (data [0] - (frames / 2) * 0.01) > 0.01)
+	{	printf ("\n\nLine %d: Bad peak value (%f should be %f) for command SFC_GET_SIGNAL_MAX.\n", __LINE__, data [0], (frames / 2) * 0.01) ;
+		exit (1) ;
+		} ;
+
+	if (sf_command (file, SFC_GET_MAX_ALL_CHANNELS, data, sizeof (double) * sfinfo.channels) == SF_FALSE)
+	{	printf ("\n\nLine %d: Command should have returned SF_TRUE.\n", __LINE__) ;
+		exit (1) ;
+		} ;
+
+	if (fabs (data [3] - (frames / 2) * 0.01) > 0.01)
+	{	printf ("\n\nLine %d: Bad peak value (%f should be %f) for command SFC_GET_MAX_ALL_CHANNELS.\n", __LINE__, data [0], (frames / 2) * 0.01) ;
+		exit (1) ;
+		} ;
+
 	/* Get the log buffer data. */
 	log_buffer [0] = 0 ;
 	sf_command	(file, SFC_GET_LOG_INFO, log_buffer, LOG_BUFFER_SIZE) ;
@@ -156,6 +182,9 @@ test_float_peak (const char *filename, int filetype)
 	/* Write a file ***without*** PEAK chunks. */
 	file = test_open_file_or_die (filename, SFM_WRITE, &sfinfo, 0, __LINE__) ;
 
+	/* Try to confuse the header writer by adding a removing the PEAK chunk. */
+	sf_command (file, SFC_SET_ADD_PEAK_CHUNK, NULL, SF_FALSE) ;
+	sf_command (file, SFC_SET_ADD_PEAK_CHUNK, NULL, SF_TRUE) ;
 	sf_command (file, SFC_SET_ADD_PEAK_CHUNK, NULL, SF_FALSE) ;
 
 	/*	Write the data in four passed. The data is designed so that peaks will
@@ -168,6 +197,17 @@ test_float_peak (const char *filename, int filetype)
 
 	file = test_open_file_or_die (filename, SFM_READ, &sfinfo, 0, __LINE__) ;
 
+	/* Check these two commands. */
+	if (sf_command (file, SFC_GET_SIGNAL_MAX, data, sizeof (double)))
+	{	printf ("\n\nLine %d: Command should have returned SF_FALSE.\n", __LINE__) ;
+		exit (1) ;
+		} ;
+
+	if (sf_command (file, SFC_GET_MAX_ALL_CHANNELS, data, sizeof (double) * sfinfo.channels))
+	{	printf ("\n\nLine %d: Command should have returned SF_FALSE.\n", __LINE__) ;
+		exit (1) ;
+		} ;
+
 	/* Get the log buffer data. */
 	log_buffer [0] = 0 ;
 	sf_command	(file, SFC_GET_LOG_INFO, log_buffer, LOG_BUFFER_SIZE) ;
