@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 2002-2004 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 2002-2005 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -25,12 +25,12 @@
 
 
 
-#include "config.h"
+#include "sfconfig.h"
 
 #include <stdio.h>
 #include <stdlib.h>
 
-#ifdef HAVE_UNISTD_H
+#if HAVE_UNISTD_H
 #include <unistd.h>
 #endif
 
@@ -53,11 +53,34 @@
 #define	M_PI		3.14159265358979323846264338
 #endif
 
-#define SIGNED_SIZEOF(x)	((int) (sizeof (x)))
 #define	LOG_BUFFER_SIZE		2048
 
+
 void
-gen_windowed_sine (double *data, int len, double maximum)
+gen_windowed_sine_float (float *data, int len, double maximum)
+{	int k ;
+
+	memset (data, 0, len * sizeof (float)) ;
+	/*
+	**	Choose a frequency of 1/32 so that it aligns perfectly with a DFT
+	**	bucket to minimise spreading of energy over more than one bucket.
+	**	Also do not want to make the frequency too high as some of the
+	**	codecs (ie gsm610) have a quite severe high frequency roll off.
+	*/
+	len /= 2 ;
+
+	for (k = 0 ; k < len ; k++)
+	{	data [k] = sin (2.0 * k * M_PI * 1.0 / 32.0 + 0.4) ;
+
+		/* Apply Hanning Window. */
+		data [k] *= maximum * (0.5 - 0.5 * cos (2.0 * M_PI * k / ((len) - 1))) ;
+		}
+
+	return ;
+} /* gen_windowed_sine_float */
+
+void
+gen_windowed_sine_double (double *data, int len, double maximum)
 {	int k ;
 
 	memset (data, 0, len * sizeof (double)) ;
@@ -77,7 +100,7 @@ gen_windowed_sine (double *data, int len, double maximum)
 		}
 
 	return ;
-} /* gen_windowed_sine */
+} /* gen_windowed_sine_double */
 
 
 void
@@ -140,6 +163,24 @@ print_test_name (const char *test, const char *filename)
 	fflush (stdout) ;
 } /* print_test_name */
 
+void
+dump_data_to_file (const char *filename, void *data, unsigned int datalen)
+{	FILE *file ;
+
+	if ((file = fopen (filename, "wb")) == NULL)
+	{	printf ("\n\nLine %d : could not open file : %s\n\n", __LINE__, filename) ;
+		exit (1) ;
+		} ;
+
+	if (fwrite (data, 1, datalen, file) != datalen)
+	{	printf ("\n\nLine %d : fwrite failed.\n\n", __LINE__) ;
+		exit (1) ;
+		} ;
+
+	fclose (file) ;
+
+} /* dump_data_to_file */
+
 /*-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-
 */
 
@@ -292,6 +333,13 @@ check_log_buffer_or_die (SNDFILE *file, int line_num)
 		exit (1) ;
 		} ;
 
+	/* Look for "Should" */
+	if (strstr (buffer, "nknown marker"))
+	{	printf ("\n\nLine %d : Log buffer contains `nknown marker'. Dumping.\n", line_num) ;
+		puts (buffer) ;
+		exit (1) ;
+		} ;
+
 	return ;
 } /* check_log_buffer_or_die */
 
@@ -385,7 +433,7 @@ dump_log_buffer (SNDFILE *file)
 } /* dump_log_buffer */
 
 SNDFILE *
-test_open_file_or_die (const char *filename, int mode, SF_INFO *sfinfo, int line_num)
+test_open_file_or_die (const char *filename, int mode, SF_INFO *sfinfo, int allow_fd, int line_num)
 {	static int count = 0 ;
 
 	SNDFILE *file ;
@@ -396,7 +444,6 @@ test_open_file_or_die (const char *filename, int mode, SF_INFO *sfinfo, int line
 	** Need to test both sf_open() and sf_open_fd().
 	** Do so alternately.
 	*/
-
 	switch (mode)
 	{	case SFM_READ :
 				modestr = "SFM_READ" ;
@@ -421,12 +468,12 @@ test_open_file_or_die (const char *filename, int mode, SF_INFO *sfinfo, int line
 				exit (1) ;
 		} ;
 
-#if (defined (__CYGWIN__) || defined (WIN32) || defined (_WIN32))
+#if (defined (WIN32) || defined (_WIN32))
 	/* Stupid fscking windows. */
 	oflags |= O_BINARY ;
 #endif
 
-	if (((++count) & 1) == 1)
+	if (allow_fd && ((++count) & 1) == 1)
 	{	int fd ;
 
 		if (omode == 0)
@@ -684,8 +731,10 @@ test_readf_double_or_die (SNDFILE *file, int pass, double *test, sf_count_t fram
 } /* test_readf_double */
 
 
+
+
 void
-test_write_short_or_die (SNDFILE *file, int pass, short *test, sf_count_t items, int line_num)
+test_write_short_or_die (SNDFILE *file, int pass, const short *test, sf_count_t items, int line_num)
 {	sf_count_t count ;
 
 	if ((count = sf_write_short (file, test, items)) != items)
@@ -703,7 +752,7 @@ test_write_short_or_die (SNDFILE *file, int pass, short *test, sf_count_t items,
 } /* test_write_short */
 
 void
-test_write_int_or_die (SNDFILE *file, int pass, int *test, sf_count_t items, int line_num)
+test_write_int_or_die (SNDFILE *file, int pass, const int *test, sf_count_t items, int line_num)
 {	sf_count_t count ;
 
 	if ((count = sf_write_int (file, test, items)) != items)
@@ -721,7 +770,7 @@ test_write_int_or_die (SNDFILE *file, int pass, int *test, sf_count_t items, int
 } /* test_write_int */
 
 void
-test_write_float_or_die (SNDFILE *file, int pass, float *test, sf_count_t items, int line_num)
+test_write_float_or_die (SNDFILE *file, int pass, const float *test, sf_count_t items, int line_num)
 {	sf_count_t count ;
 
 	if ((count = sf_write_float (file, test, items)) != items)
@@ -739,7 +788,7 @@ test_write_float_or_die (SNDFILE *file, int pass, float *test, sf_count_t items,
 } /* test_write_float */
 
 void
-test_write_double_or_die (SNDFILE *file, int pass, double *test, sf_count_t items, int line_num)
+test_write_double_or_die (SNDFILE *file, int pass, const double *test, sf_count_t items, int line_num)
 {	sf_count_t count ;
 
 	if ((count = sf_write_double (file, test, items)) != items)
@@ -758,7 +807,7 @@ test_write_double_or_die (SNDFILE *file, int pass, double *test, sf_count_t item
 
 
 void
-test_writef_short_or_die (SNDFILE *file, int pass, short *test, sf_count_t frames, int line_num)
+test_writef_short_or_die (SNDFILE *file, int pass, const short *test, sf_count_t frames, int line_num)
 {	sf_count_t count ;
 
 	if ((count = sf_writef_short (file, test, frames)) != frames)
@@ -776,7 +825,7 @@ test_writef_short_or_die (SNDFILE *file, int pass, short *test, sf_count_t frame
 } /* test_writef_short */
 
 void
-test_writef_int_or_die (SNDFILE *file, int pass, int *test, sf_count_t frames, int line_num)
+test_writef_int_or_die (SNDFILE *file, int pass, const int *test, sf_count_t frames, int line_num)
 {	sf_count_t count ;
 
 	if ((count = sf_writef_int (file, test, frames)) != frames)
@@ -794,7 +843,7 @@ test_writef_int_or_die (SNDFILE *file, int pass, int *test, sf_count_t frames, i
 } /* test_writef_int */
 
 void
-test_writef_float_or_die (SNDFILE *file, int pass, float *test, sf_count_t frames, int line_num)
+test_writef_float_or_die (SNDFILE *file, int pass, const float *test, sf_count_t frames, int line_num)
 {	sf_count_t count ;
 
 	if ((count = sf_writef_float (file, test, frames)) != frames)
@@ -812,7 +861,7 @@ test_writef_float_or_die (SNDFILE *file, int pass, float *test, sf_count_t frame
 } /* test_writef_float */
 
 void
-test_writef_double_or_die (SNDFILE *file, int pass, double *test, sf_count_t frames, int line_num)
+test_writef_double_or_die (SNDFILE *file, int pass, const double *test, sf_count_t frames, int line_num)
 {	sf_count_t count ;
 
 	if ((count = sf_writef_double (file, test, frames)) != frames)
@@ -830,6 +879,86 @@ test_writef_double_or_die (SNDFILE *file, int pass, double *test, sf_count_t fra
 } /* test_writef_double */
 
 
+void
+delete_file (int format, const char *filename)
+{	char rsrc_name [512], *fname ;
+
+	unlink (filename) ;
+
+	if ((format & SF_FORMAT_TYPEMASK) != SF_FORMAT_SD2)
+		return ;
+
+	/*
+	** Now try for a resource fork stored as a separate file.
+	** Grab the un-adulterated filename again.
+	*/
+	snprintf (rsrc_name, sizeof (rsrc_name), "%s", filename) ;
+
+	if ((fname = strrchr (rsrc_name, '/')) != NULL)
+		fname ++ ;
+	else if ((fname = strrchr (rsrc_name, '\\')) != NULL)
+		fname ++ ;
+	else
+		fname = rsrc_name ;
+
+	memmove (fname + 2, fname, strlen (fname) + 1) ;
+	fname [0] = '.' ;
+	fname [1] = '_' ;
+
+	unlink (rsrc_name) ;
+} /* delete_file */
+
+static int allowed_open_files = -1 ;
+
+void
+count_open_files (void)
+{
+#if (defined (WIN32) || defined (_WIN32))
+	return ;
+#else
+	int k, count = 0 ;
+	struct stat statbuf ;
+
+	if (allowed_open_files > 0)
+		return ;
+
+	for (k = 0 ; k < 1024 ; k++)
+		if (fstat (k, &statbuf) == 0)
+			count ++ ;
+
+	allowed_open_files = count ;
+#endif
+} /* count_open_files */
+
+void
+increment_open_file_count (void)
+{	allowed_open_files ++ ;
+} /* increment_open_file_count */
+
+void
+check_open_file_count_or_die (int lineno)
+{
+#if (defined (WIN32) || defined (_WIN32))
+	lineno = 0 ;
+	return ;
+#else
+	int k, count = 0 ;
+	struct stat statbuf ;
+
+	if (allowed_open_files < 0)
+		count_open_files () ;
+
+	for (k = 0 ; k < 1024 ; k++)
+		if (fstat (k, &statbuf) == 0)
+			count ++ ;
+
+	if (count > allowed_open_files)
+	{	printf ("\nLine %d : number of open files (%d) > allowed (%d).\n\n", lineno, count, allowed_open_files) ;
+		exit (1) ;
+		} ;
+#endif
+} /* check_open_file_count_or_die */
+
 
 
 
